==> mdpws-model-1.1.0-sources.jar: org/somda/sdc/mdpws/model/SafetyInfoType.java <==

package org.somda.sdc.mdpws.model;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.CopyStrategy2;
import org.jvnet.jaxb2_commons.lang.CopyTo2;
import org.jvnet.jaxb2_commons.lang.JAXBCopyStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;
import org.w3c.dom.Element;


/**
 * Container element for embedding safety information in a SOAP message header.
 * 
 * <p>Java class for SafetyInfoType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SafetyInfoType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="DualChannel" type="{http://standards.ieee.org/downloads/11073/11073-20702-2016}DualChannelType" minOccurs="0"/&gt;
 *         &lt;element name="SafetyContext" type="{http://standards.ieee.org/downloads/11073/11073-20702-2016}SafetyContextType" minOccurs="0"/&gt;
 *         &lt;any processContents='skip' namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;anyAttribute processContents='skip' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SafetyInfoType", namespace = "http://standards.ieee.org/downloads/11073/11073-20702-2016", propOrder = {
    "dualChannel",
    "safetyContext",
    "any"
})
public class SafetyInfoType implements Cloneable, CopyTo2, ToString2
{

    @XmlElement(name = "DualChannel", namespace = "http://standards.ieee.org/downloads/11073/11073-20702-2016")
    protected DualChannelType dualChannel;
    @XmlElement(name = "SafetyContext", namespace = "http://standards.ieee.org/downloads/11073/11073-20702-2016")
    protected SafetyContextType safetyContext;
    @XmlAnyElement
    protected List<Element> any;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Ruft den Wert der dualChannel-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link DualChannelType }
     *     
     */
    public DualChannelType getDualChannel() {
        return dualChannel;
    }

    /**
     * Legt den Wert der dualChannel-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link DualChannelType }
     *     
     */
    public void setDualChannel(DualChannelType value) {
        this.dualChannel = value;
    }

    /**
     * Ruft den Wert der safetyContext-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link SafetyContextType }
     *     
     */
    public SafetyContextType getSafetyContext() {
        return safetyContext;
    }

    /**
     * Legt den Wert der safetyContext-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link SafetyContextType }
     *     
     */
    public void setSafetyContext(SafetyContextType value) {
        this.safetyContext = value;
    }

    /**
     * Gets the value of the any property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the any property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAny().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Element }
     * 
     * 
     */
    public List<Element> getAny() {
        if (any == null) {
            any = new ArrayList<Element>();
        }
        return this.any;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public void setAny(List<Element> value) {
        this.any = null;
        if (value!= null) {
            List<Element> draftl = this.getAny();
            draftl.addAll(value);
        }
    }

    public Object clone() {
        return copyTo(createNewInstance());
    }

    public Object copyTo(Object target) {
        final CopyStrategy2 strategy = JAXBCopyStrategy.INSTANCE2;
        return copyTo(null, target, strategy);
    }

    public Object copyTo(ObjectLocator locator, Object target, CopyStrategy2 strategy) {
        final Object draftCopy = ((target == null)?createNewInstance():target);
        if (draftCopy instanceof SafetyInfoType) {
            final SafetyInfoType copy = ((SafetyInfoType) draftCopy);
            {
                Boolean dualChannelShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, (this.dualChannel!= null));
                if (dualChannelShouldBeCopiedAndSet == Boolean.TRUE) {
                    DualChannelType sourceDualChannel;
                    sourceDualChannel = this.getDualChannel();
                    DualChannelType copyDualChannel = ((DualChannelType) strategy.copy(LocatorUtils.property(locator, "dualChannel", sourceDualChannel), sourceDualChannel, (this.dualChannel!= null)));
                    copy.setDualChannel(copyDualChannel);
                } else {
                    if (dualChannelShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.dualChannel = null;
                    }
                }
            }
            {
                Boolean safetyContextShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, (this.safetyContext!= null));
                if (safetyContextShouldBeCopiedAndSet == Boolean.TRUE) {
                    SafetyContextType sourceSafetyContext;
                    sourceSafetyContext = this.getSafetyContext();
                    SafetyContextType copySafetyContext = ((SafetyContextType) strategy.copy(LocatorUtils.property(locator, "safetyContext", sourceSafetyContext), sourceSafetyContext, (this.safetyContext!= null)));
                    copy.setSafetyContext(copySafetyContext);
                } else {
                    if (safetyContextShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.safetyContext = null;
                    }
                }
            }
            {
                Boolean anyShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, ((this.any!= null)&&(!this.any.isEmpty())));
                if (anyShouldBeCopiedAndSet == Boolean.TRUE) {
                    List<Element> sourceAny;
                    sourceAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
                    @SuppressWarnings("unchecked")
                    List<Element> copyAny = ((List<Element> ) strategy.copy(LocatorUtils.property(locator, "any", sourceAny), sourceAny, ((this.any!= null)&&(!this.any.isEmpty()))));
                    copy.setAny(copyAny);
                } else {
                    if (anyShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.any = null;
                    }
                }
            }
        }
        return draftCopy;
    }

    public Object createNewInstance() {
        return new SafetyInfoType();
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final SafetyInfoType that = ((SafetyInfoType) object);
        {
            DualChannelType leftDualChannel;
            leftDualChannel = this.getDualChannel();
            DualChannelType rightDualChannel;
            rightDualChannel = that.getDualChannel();
            if (this.dualChannel!= null) {
                if (that.dualChannel!= null) {
                    if (!leftDualChannel.equals(rightDualChannel)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.dualChannel!= null) {
                    return false;
                }
            }
        }
        {
            SafetyContextType leftSafetyContext;
            leftSafetyContext = this.getSafetyContext();
            SafetyContextType rightSafetyContext;
            rightSafetyContext = that.getSafetyContext();
            if (this.safetyContext!= null) {
                if (that.safetyContext!= null) {
                    if (!leftSafetyContext.equals(rightSafetyContext)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.safetyContext!= null) {
                    return false;
                }
            }
        }
        {
            List<Element> leftAny;
            leftAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            List<Element> rightAny;
            rightAny = (((that.any!= null)&&(!that.any.isEmpty()))?that.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    if (!leftAny.equals(rightAny)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            DualChannelType theDualChannel;
            theDualChannel = this.getDualChannel();
            if (this.dualChannel!= null) {
                currentHashCode += theDualChannel.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            SafetyContextType theSafetyContext;
            theSafetyContext = this.getSafetyContext();
            if (this.safetyContext!= null) {
                currentHashCode += theSafetyContext.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<Element> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                currentHashCode += theAny.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            DualChannelType theDualChannel;
            theDualChannel = this.getDualChannel();
            strategy.appendField(locator, this, "dualChannel", buffer, theDualChannel, (this.dualChannel!= null));
        }
        {
            SafetyContextType theSafetyContext;
            theSafetyContext = this.getSafetyContext();
            strategy.appendField(locator, this, "safetyContext", buffer, theSafetyContext, (this.safetyContext!= null));
        }
        {
            List<Element> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            strategy.appendField(locator, this, "any", buffer, theAny, ((this.any!= null)&&(!this.any.isEmpty())));
        }
        return buffer;
    }

}

==> mdpws-model-4.0.0-sources.jar: org/somda/sdc/mdpws/model/SafetyInfoType.java <==

package org.somda.sdc.mdpws.model;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.CopyStrategy2;
import org.jvnet.jaxb2_commons.lang.CopyTo2;
import org.jvnet.jaxb2_commons.lang.JAXBCopyStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;
import org.w3c.dom.Element;


/**
 * Container element for embedding safety information in a SOAP message header.
 * 
 * <p>Java class for SafetyInfoType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SafetyInfoType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="DualChannel" type="{http://standards.ieee.org/downloads/11073/11073-20702-2016}DualChannelType" minOccurs="0"/&gt;
 *         &lt;element name="SafetyContext" type="{http://standards.ieee.org/downloads/11073/11073-20702-2016}SafetyContextType" minOccurs="0"/&gt;
 *         &lt;any processContents='skip' namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;anyAttribute processContents='skip' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SafetyInfoType", namespace = "http://standards.ieee.org/downloads/11073/11073-20702-2016", propOrder = {
    "dualChannel",
    "safetyContext",
    "any"
})
public class SafetyInfoType implements Cloneable, CopyTo2, ToString2
{

    @XmlElement(name = "DualChannel", namespace = "http://standards.ieee.org/downloads/11073/11073-20702-2016")
    protected DualChannelType dualChannel;
    @XmlElement(name = "SafetyContext", namespace = "http://standards.ieee.org/downloads/11073/11073-20702-2016")
    protected SafetyContextType safetyContext;
    @XmlAnyElement
    protected List<Element> any;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Gets the value of the dualChannel property.
     * 
     * @return
     *     possible object is
     *     {@link DualChannelType }
     *     
     */
    public DualChannelType getDualChannel() {
        return dualChannel;
    }

    /**
     * Sets the value of the dualChannel property.
     * 
     * @param value
     *     allowed object is
     *     {@link DualChannelType }
     *     
     */
    public void setDualChannel(DualChannelType value) {
        this.dualChannel = value;
    }

    /**
     * Gets the value of the safetyContext property.
     * 
     * @return
     *     possible object is
     *     {@link SafetyContextType }
     *     
     */
    public SafetyContextType getSafetyContext() {
        return safetyContext;
    }

    /**
     * Sets the value of the safetyContext property.
     * 
     * @param value
     *     allowed object is
     *     {@link SafetyContextType }
     *     
     */
    public void setSafetyContext(SafetyContextType value) {
        this.safetyContext = value;
    }

    /**
     * Gets the value of the any property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the any property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAny().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Element }
     * 
     * 
     */
    public List<Element> getAny() {
        if (any == null) {
            any = new ArrayList<Element>();
        }
        return this.any;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public void setAny(List<Element> value) {
        this.any = null;
        if (value!= null) {
            List<Element> draftl = this.getAny();
            draftl.addAll(value);
        }
    }

    @Override
    public Object clone() {
        return copyTo(createNewInstance());
    }

    @Override
    public Object copyTo(Object target) {
        final CopyStrategy2 strategy = JAXBCopyStrategy.getInstance();
        return copyTo(null, target, strategy);
    }

    @Override
    public Object copyTo(ObjectLocator locator, Object target, CopyStrategy2 strategy) {
        final Object draftCopy = ((target == null)?createNewInstance():target);
        if (draftCopy instanceof SafetyInfoType) {
            final SafetyInfoType copy = ((SafetyInfoType) draftCopy);
            {
                Boolean dualChannelShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, (this.dualChannel!= null));
                if (dualChannelShouldBeCopiedAndSet == Boolean.TRUE) {
                    DualChannelType sourceDualChannel;
                    sourceDualChannel = this.getDualChannel();
                    DualChannelType copyDualChannel = ((DualChannelType) strategy.copy(LocatorUtils.property(locator, "dualChannel", sourceDualChannel), sourceDualChannel, (this.dualChannel!= null)));
                    copy.setDualChannel(copyDualChannel);
                } else {
                    if (dualChannelShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.dualChannel = null;
                    }
                }
            }
            {
                Boolean safetyContextShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, (this.safetyContext!= null));
                if (safetyContextShouldBeCopiedAndSet == Boolean.TRUE) {
                    SafetyContextType sourceSafetyContext;
                    sourceSafetyContext = this.getSafetyContext();
                    SafetyContextType copySafetyContext = ((SafetyContextType) strategy.copy(LocatorUtils.property(locator, "safetyContext", sourceSafetyContext), sourceSafetyContext, (this.safetyContext!= null)));
                    copy.setSafetyContext(copySafetyContext);
                } else {
                    if (safetyContextShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.safetyContext = null;
                    }
                }
            }
            {
                Boolean anyShouldBeCopiedAndSet = strategy.shouldBeCopiedAndSet(locator, ((this.any!= null)&&(!this.any.isEmpty())));
                if (anyShouldBeCopiedAndSet == Boolean.TRUE) {
                    List<Element> sourceAny;
                    sourceAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
                    @SuppressWarnings("unchecked")
                    List<Element> copyAny = ((List<Element> ) strategy.copy(LocatorUtils.property(locator, "any", sourceAny), sourceAny, ((this.any!= null)&&(!this.any.isEmpty()))));
                    copy.setAny(copyAny);
                } else {
                    if (anyShouldBeCopiedAndSet == Boolean.FALSE) {
                        copy.any = null;
                    }
                }
            }
        }
        return draftCopy;
    }

    @Override
    public Object createNewInstance() {
        return new SafetyInfoType();
    }

    @Override
    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final SafetyInfoType that = ((SafetyInfoType) object);
        {
            DualChannelType leftDualChannel;
            leftDualChannel = this.getDualChannel();
            DualChannelType rightDualChannel;
            rightDualChannel = that.getDualChannel();
            if (this.dualChannel!= null) {
                if (that.dualChannel!= null) {
                    if (!leftDualChannel.equals(rightDualChannel)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.dualChannel!= null) {
                    return false;
                }
            }
        }
        {
            SafetyContextType leftSafetyContext;
            leftSafetyContext = this.getSafetyContext();
            SafetyContextType rightSafetyContext;
            rightSafetyContext = that.getSafetyContext();
            if (this.safetyContext!= null) {
                if (that.safetyContext!= null) {
                    if (!leftSafetyContext.equals(rightSafetyContext)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.safetyContext!= null) {
                    return false;
                }
            }
        }
        {
            List<Element> leftAny;
            leftAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            List<Element> rightAny;
            rightAny = (((that.any!= null)&&(!that.any.isEmpty()))?that.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    if (!leftAny.equals(rightAny)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    return false;
                }
            }
        }
        return true;
    }

    @Override
    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            DualChannelType theDualChannel;
            theDualChannel = this.getDualChannel();
            if (this.dualChannel!= null) {
                currentHashCode += theDualChannel.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            SafetyContextType theSafetyContext;
            theSafetyContext = this.getSafetyContext();
            if (this.safetyContext!= null) {
                currentHashCode += theSafetyContext.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<Element> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                currentHashCode += theAny.hashCode();
            }
        }
        return currentHashCode;
    }

    @Override
    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.getInstance();
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    @Override
    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    @Override
    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            DualChannelType theDualChannel;
            theDualChannel = this.getDualChannel();
            strategy.appendField(locator, this, "dualChannel", buffer, theDualChannel, (this.dualChannel!= null));
        }
        {
            SafetyContextType theSafetyContext;
            theSafetyContext = this.getSafetyContext();
            strategy.appendField(locator, this, "safetyContext", buffer, theSafetyContext, (this.safetyContext!= null));
        }
        {
            List<Element> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            strategy.appendField(locator, this, "any", buffer, theAny, ((this.any!= null)&&(!this.any.isEmpty())));
        }
        return buffer;
    }

}
